@@ -16,9 +16,10 @@ var AccountsMonitor = class {
 
         this._app = Gio.Application.get_default();
 
-        if (!this._app.isTestInstance)
+        if (!this._app.isTestInstance) {
             this._app.connect('prepare-shutdown',
                               this._onPrepareShutdown.bind(this));
+        }
 
         let factory = new ClientFactory();
         factory.add_channel_features([Tp.Channel.get_feature_quark_group()]);
