@@ -285,9 +285,10 @@ var Application = GObject.registerClass({
                 action.connect('activate', actionEntry.activate);
             if (actionEntry.change_state)
                 action.connect('change-state', actionEntry.change_state);
-            if (actionEntry.accels)
+            if (actionEntry.accels) {
                 this.set_accels_for_action(`app.${actionEntry.name}`,
                                            actionEntry.accels);
+            }
             this.add_action(action);
         });
 
@@ -438,17 +439,19 @@ var Application = GObject.registerClass({
                        map[a].service == matchedId;
             });
 
-            if (matches.length)
+            if (matches.length) {
                 joinAction.activate(new GLib.Variant('(ssu)',
                                                      [matches[0], `#${room}`, time]));
-            else
+            } else {
                 this._createAccount(matchedId, server, port, a => {
-                    if (a)
+                    if (a) {
                         joinAction.activate(new GLib.Variant('(ssu)', [
                             a.get_object_path(),
                             `#${room}`, time
                         ]));
+                    }
                 });
+            }
         });
     }
 
@@ -697,14 +700,16 @@ var Application = GObject.registerClass({
         if (status == Tp.ConnectionStatus.DISCONNECTED) {
             let reason = account.connection_status_reason;
 
-            if (reason == Tp.ConnectionStatusReason.NAME_IN_USE)
+            if (reason == Tp.ConnectionStatusReason.NAME_IN_USE) {
                 if (this._retryNickRequest(account))
                     return;
+            }
 
             if (reason == Tp.ConnectionStatusReason.NETWORK_ERROR ||
-                reason == Tp.ConnectionStatusReason.NONE_SPECIFIED)
+                reason == Tp.ConnectionStatusReason.NONE_SPECIFIED) {
                 if (this._retryServerRequest(account))
                     return;
+            }
 
             if (reason != Tp.ConnectionStatusReason.REQUESTED) {
                 let strReason = Object.keys(Tp.ConnectionStatusReason)[reason];
@@ -817,7 +822,8 @@ var Application = GObject.registerClass({
                 'Danny Mølgaard <moelgaard.dmp@gmail.com>',
                 'Justyn Temme <Justyntemme@gmail.com>',
                 'unkemptArc99 <abhishekbhardwaj540@gmail.com>',
-                'Oscar Shrimpton <oscar.shrimpton.personal@gmail.com>'
+                'Oscar Shrimpton <oscar.shrimpton.personal@gmail.com>',
+                'Daronion <stefanosdimos.98@gmail.com>'
             ],
             artists: [
                 'Sam Hewitt <hewittsamuel@gmail.com>',
