@@ -530,12 +530,10 @@ var ChatView = GObject.registerClass({
     }
 
     _onDestroy() {
-        for (let i = 0; i < this._channelSignals.length; i++)
-            this._channel.disconnect(this._channelSignals[i]);
+        this._channelSignals.forEach(id => this._channel.disconnect(id));
         this._channelSignals = [];
 
-        for (let i = 0; i < this._roomSignals.length; i++)
-            this._room.disconnect(this._roomSignals[i]);
+        this._roomSignals.forEach(id => this._room.disconnect(id));
         this._roomSignals = [];
 
         if (this._roomFocusChangedId)
@@ -546,9 +544,10 @@ var ChatView = GObject.registerClass({
             GLib.source_remove(this._backlogTimeoutId);
         this._backlogTimeoutId = 0;
 
-        if (this._nickStatusChangedId)
+        if (this._nickStatusChangedId) {
             this._userTracker.unwatchRoomStatus(this._room,
                                                 this._nickStatusChangedId);
+        }
         this._nickStatusChangedId = 0;
         this._userTracker = null;
 
@@ -597,10 +596,11 @@ var ChatView = GObject.registerClass({
         let nick = this._pendingLogs[0].nick;
         let type = this._pendingLogs[0].messageType;
         let maxNum = this._pendingLogs.length - this._initialPending.length;
-        for (let i = 0; i < maxNum; i++)
+        for (let i = 0; i < maxNum; i++) {
             if (this._pendingLogs[i].nick != nick ||
                 this._pendingLogs[i].messageType != type)
                 return this._pendingLogs.splice(i);
+        }
         return [];
     }
 
@@ -610,12 +610,13 @@ var ChatView = GObject.registerClass({
 
         let numLogs = logs.length;
         let pos;
-        for (pos = numLogs - pending.length; pos < numLogs; pos++)
+        for (pos = numLogs - pending.length; pos < numLogs; pos++) {
             if (logs[pos].nick == firstPending.nick &&
                 logs[pos].text == firstPending.text &&
                 logs[pos].timestamp == firstPending.timestamp &&
                 logs[pos].messageType == firstPending.messageType)
                 break;
+        }
         // Remove entries that are also in pending (if any), then
         // add the entries from pending
         logs.splice.apply(logs, [pos, numLogs, ...pending]);
@@ -932,8 +933,7 @@ var ChatView = GObject.registerClass({
             this._removePendingMark(id);
 
         if (this._channel) {
-            for (let i = 0; i < this._channelSignals.length; i++)
-                this._channel.disconnect(this._channelSignals[i]);
+            this._channelSignals.forEach(id => this._channel.disconnect(id));
             this._channelSignals = [];
         }
 
@@ -1093,12 +1093,14 @@ var ChatView = GObject.registerClass({
         }
 
         let stats = [];
-        if (this._statusCount.joined > 0)
+        if (this._statusCount.joined > 0) {
             stats.push(ngettext('%d user joined',
                                 '%d users joined', this._statusCount.joined).format(this._statusCount.joined));
-        if (this._statusCount.left > 0)
+        }
+        if (this._statusCount.left > 0) {
             stats.push(ngettext('%d user left',
                                 '%d users left', this._statusCount.left).format(this._statusCount.left));
+        }
         // TODO: How do we update the arrow direction when text direction change?
         let iter = buffer.get_iter_at_mark(headerMark);
         let tags = [this._lookupTag('status'), headerTag];
@@ -1296,7 +1298,7 @@ var ChatView = GObject.registerClass({
             tags.push(this._lookupTag('message'));
         }
 
-        if (highlight)
+        if (highlight && this._room.type != Tp.HandleType.CONTACT)
             tags.push(this._lookupTag('highlight'));
 
         let params = this._room.account.dup_parameters_vardict().deep_unpack();
@@ -1331,18 +1333,20 @@ var ChatView = GObject.registerClass({
         }
         this._insertWithTags(iter, text.substr(pos), tags);
 
-        if (highlight && message.pendingId)
+        if (highlight && message.pendingId) {
             this._pending.set(message.pendingId,
                               this._view.buffer.create_mark(null, iter, true));
+        }
     }
 
     _onNickStatusChanged(baseNick, status) {
         if (this._room.type == Tp.HandleType.CONTACT &&
             status == Tp.ConnectionPresenceType.OFFLINE &&
-            this._room.channel)
+            this._room.channel) {
             this._room.channel.ack_all_pending_messages_async(channel => {
                 channel.close_async(null);
             });
+        }
 
         let nickTagName = this._getNickTagName(baseNick);
         let nickTag = this._lookupTag(nickTagName);
@@ -1386,12 +1390,13 @@ var ChatView = GObject.registerClass({
 
         let actualNickName = view.get_buffer().get_slice(start, end, false);
 
-        if (!tag._popover)
+        if (!tag._popover) {
             tag._popover = new UserPopover({
                 relative_to: this._view,
                 userTracker: this._userTracker,
                 room: this._room
             });
+        }
 
         tag._popover.nickname = actualNickName;
 
