@@ -185,7 +185,6 @@ var JoinDialog = GObject.registerClass({
         this._connectionCombo.remove_all();
 
         let names = [...this._accounts.keys()].sort((a, b) => {
-            // TODO: figure out combo box sorting
             return (a < b) ? -1 : ((a > b) ? 1 : 0);
         });
         for (let i = 0; i < names.length; i++)
@@ -203,9 +202,10 @@ var JoinDialog = GObject.registerClass({
     _updateCanJoin() {
         let sensitive = false;
 
-        if (this._page == DialogPage.MAIN)
+        if (this._page == DialogPage.MAIN) {
             sensitive = this._connectionCombo.get_active() > -1  &&
                         this._serverRoomList.can_join;
+        }
 
         this._joinButton.sensitive = sensitive;
         this.set_default_response(sensitive ?
