@@ -102,8 +102,6 @@ var RoomRow = GObject.registerClass({
 
         let pending = this._room.channel.dup_pending_messages();
         let nPending = pending.length;
-        if (!this._room.channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP))
-            return [nPending, nPending];
 
         let highlights = pending.filter(m => {
             let [text] = m.to_text();
@@ -122,7 +120,7 @@ var RoomRow = GObject.registerClass({
     _onConnectionStatusChanged() {
         let status = this._getConnectionStatus();
         // Show loading indicator if joining a room takes more than 3 seconds
-        if (status == Tp.ConnectionStatus.CONNECTED && !this._room.channel)
+        if (status == Tp.ConnectionStatus.CONNECTED && !this._room.channel) {
             this._connectingTimeoutId = GLib.timeout_add_seconds(GLib.PRIORITY_DEFAULT, 3, () => {
                 this._connectingTimeoutId = 0;
 
@@ -131,8 +129,9 @@ var RoomRow = GObject.registerClass({
                 this._eventStack.visible_child_name = 'connecting';
                 return GLib.SOURCE_REMOVE;
             });
-        else
+        } else {
             this._eventStack.visible_child_name = 'messages';
+        }
     }
 
     _updatePending() {
@@ -155,11 +154,12 @@ var RoomRow = GObject.registerClass({
             return;
         this._eventStack.visible_child_name = 'messages';
 
-        for (let signal of ['message-received', 'pending-message-removed'])
+        for (let signal of ['message-received', 'pending-message-removed']) {
             this._channelSignals.push(
                 this._room.channel.connect(signal,
                                            this._updatePending.bind(this))
             );
+        }
         this._updatePending();
     }
 
@@ -524,11 +524,8 @@ class RoomList extends Gtk.ListBox {
     }
 
     _roomToRowIndex(index) {
-        let nChildren = this.get_children().length;
-        for (let i = 0, roomIndex = 0; i < nChildren; i++)
-            if (this.get_row_at_index(i).room && roomIndex++ == index)
-                return i;
-        return -1;
+        let roomRows = this.get_children().filter(r => r instanceof RoomRow);
+        return index < roomRows.length ? roomRows[index].get_index() : -1;
     }
 
     _getRoomRowAtIndex(index) {
