@@ -6,6 +6,8 @@ const { AccountsMonitor } = imports.accountsMonitor;
 const { RoomManager } = imports.roomManager;
 const Utils = imports.utils;
 
+const SHELL_CLIENT_PREFIX = 'org.freedesktop.Telepathy.Client.GnomeShell';
+
 const SASLAuthenticationIface = '<node> \
 <interface name="org.freedesktop.Telepathy.Channel.Interface.SASLAuthentication"> \
 <method name="StartMechanismWithData"> \
@@ -59,13 +61,14 @@ class SASLAuthHandler {
     }
 
     _onPasswordReady(password) {
-        if (password)
+        if (password) {
             this._proxy.StartMechanismWithDataRemote('X-TELEPATHY-PASSWORD',
                                                      password);
-        else
+        } else {
             this._proxy.AbortSASLRemote(SASLAbortReason.USER_ABORT,
                                         'Password not available',
                                         this._resetPrompt.bind(this));
+        }
     }
 
     _onSASLStatusChanged(proxy, sender, [status]) {
@@ -131,6 +134,47 @@ class TelepathyClient extends Tp.BaseClient {
         });
         this._accountsMonitor = AccountsMonitor.getDefault();
         this._accountsMonitor.prepare(this._onPrepared.bind(this));
+
+        this._shellHandlesPrivateChats = false;
+
+        // Track whether gnome-shell's built-in chat client is
+        // running; unfortunately it uses :uniquify-name, so
+        // we cannot simply use Gio.watch_bus_name()
+        let conn = this._app.get_dbus_connection();
+        conn.signal_subscribe(
+            'org.freedesktop.DBus', /* sender */
+            'org.freedesktop.DBus', /* iface */
+            'NameOwnerChanged', /* member */
+            '/org/freedesktop/DBus', /* path */
+            SHELL_CLIENT_PREFIX, /* arg0 */
+            Gio.DBusSignalFlags.MATCH_ARG0_NAMESPACE,
+            (_conn, _sender, _path, _iface, _signal, params) => {
+                let [name_, oldOwner_, newOwner] = params.deep_unpack();
+                this._shellHandlesPrivateChats = (newOwner != '');
+            });
+
+        conn.call(
+            'org.freedesktop.DBus',
+            '/org/freedesktop/DBus',
+            'org.freedesktop.DBus',
+            'ListNames',
+            null, /* params */
+            new GLib.VariantType('(as)'),
+            Gio.DBusCallFlags.NONE,
+            -1,
+            null, /* cancellable */
+            (_o, res) => {
+                let names = [];
+
+                try {
+                    [names] = conn.call_finish(res).deep_unpack();
+                } catch (e) {
+                    debug(`Failed to list bus names: ${e}`);
+                }
+
+                this._shellHandlesPrivateChats =
+                    names.find(n => n.startsWith(SHELL_CLIENT_PREFIX)) != null;
+            });
     }
 
     _onPrepared() {
@@ -200,9 +244,10 @@ class TelepathyClient extends Tp.BaseClient {
 
         this._networkMonitor.connect('network-changed',
                                      this._onNetworkChanged.bind(this));
-        if (this._networkMonitor.state_valid)
+        if (this._networkMonitor.state_valid) {
             this._onNetworkChanged(this._networkMonitor,
                                    this._networkMonitor.network_available);
+        }
     }
 
     _onNetworkChanged(mon, connected) {
@@ -620,9 +665,19 @@ class TelepathyClient extends Tp.BaseClient {
         if (!room.should_highlight_message(nick, text))
             return;
 
-        /* Translators: This is the title of the notification announcing a newly
-	   received message, in the form "user-nickname in room-display-name" */
-        let summary = _('%s in %s').format(nick, room.display_name);
+        if (this._shellHandlesPrivateChats && room.type == Tp.HandleType.CONTACT)
+            return;
+
+        let summary;
+
+        if (room.type == Tp.HandleType.CONTACT) {
+            summary = '%s'.format(nick);
+        } else {
+            /* Translators: This is the title of the notification announcing a newly
+               received message, in the form "user-nickname in room-display-name" */
+            summary = _('%s in %s').format(nick, room.display_name);
+        }
+
         let notification = this._createNotification(room, summary, text);
         this._app.send_notification(this._getPendingNotificationID(room, id), notification);
     }
